tdub.data
---------

A module for handling our data.

.. currentmodule:: tdub.data

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   Region
   SampleInfo

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   avoids_for
   branches_from
   categorize_branches
   features_for
   files_for_tree
   quick_files
   selection_as_numexpr
   selection_as_root
   selection_branches
   selection_for

Reference
^^^^^^^^^

.. autoclass:: Region
   :inherited-members:

.. autofunction:: tdub.data.Region.from_str

.. autoclass:: SampleInfo
   :members:

.. autofunction:: avoids_for
.. autofunction:: branches_from
.. autofunction:: categorize_branches
.. autofunction:: features_for
.. autofunction:: files_for_tree
.. autofunction:: quick_files
.. autofunction:: selection_as_numexpr
.. autofunction:: selection_as_root
.. autofunction:: selection_branches
.. autofunction:: selection_for
